##  Next Step
[Step 2: Enrich Data](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-enrich-data?locale=en-US&state=PRODUCTION&version=CLOUD "Enrich your data by evaluating application criticality and bringing in technology lifecycle information.")
